@@ -60,6 +60,11 @@ pub enum OdsError {
     Password,
     /// Worksheet not found
     WorksheetNotFound(String),
+
+    /// XML attribute error
+    AttrError(quick_xml::events::attributes::AttrError),
+    /// XML encoding error
+    EncodingError(quick_xml::encoding::EncodingError),
 }
 
 /// Ods reader options
@@ -74,6 +79,8 @@ from_err!(zip::result::ZipError, OdsError, Zip);
 from_err!(quick_xml::Error, OdsError, Xml);
 from_err!(std::string::ParseError, OdsError, Parse);
 from_err!(std::num::ParseFloatError, OdsError, ParseFloat);
+from_err!(quick_xml::events::attributes::AttrError, OdsError, Xml);
+from_err!(quick_xml::encoding::EncodingError, OdsError, Xml);
 
 impl std::fmt::Display for OdsError {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
@@ -94,6 +101,8 @@ impl std::fmt::Display for OdsError {
             }
             OdsError::Password => write!(f, "Workbook is password protected"),
             OdsError::WorksheetNotFound(name) => write!(f, "Worksheet '{name}' not found"),
+            OdsError::AttrError(e) => write!(f, "XML attribute Error: {e}"),
+            OdsError::EncodingError(e) => write!(f, "XML encoding Error: {e}"),
         }
     }
 }
@@ -107,6 +116,8 @@ impl std::error::Error for OdsError {
             OdsError::Parse(e) => Some(e),
             OdsError::ParseInt(e) => Some(e),
             OdsError::ParseFloat(e) => Some(e),
+            OdsError::AttrError(e) => Some(e),
+            OdsError::EncodingError(e) => Some(e),
             _ => None,
         }
     }
@@ -243,10 +254,11 @@ fn check_for_password_protected<RS: Read + Seek>(zip: &mut ZipArchive<RS>) -> Re
     let mut reader = match zip.by_name("META-INF/manifest.xml") {
         Ok(f) => {
             let mut r = XmlReader::from_reader(BufReader::new(f));
-            r.check_end_names(false)
-                .trim_text(false)
-                .check_comments(false)
-                .expand_empty_elements(true);
+            let config = r.config_mut();
+            config.check_end_names = false;
+            config.trim_text(false);
+            config.check_comments = false;
+            config.expand_empty_elements = true;
             r
         }
         Err(ZipError::FileNotFound) => return Err(OdsError::FileNotFound("META-INF/manifest.xml")),
@@ -287,10 +299,11 @@ fn parse_content<RS: Read + Seek>(mut zip: ZipArchive<RS>) -> Result<Content, Od
     let mut reader = match zip.by_name("content.xml") {
         Ok(f) => {
             let mut r = XmlReader::from_reader(BufReader::new(f));
-            r.check_end_names(false)
-                .trim_text(false)
-                .check_comments(false)
-                .expand_empty_elements(true);
+            let config = r.config_mut();
+            config.check_end_names = false;
+            config.trim_text(false);
+            config.check_comments = false;
+            config.expand_empty_elements = true;
             r
         }
         Err(ZipError::FileNotFound) => return Err(OdsError::FileNotFound("content.xml")),
@@ -307,7 +320,7 @@ fn parse_content<RS: Read + Seek>(mut zip: ZipArchive<RS>) -> Result<Content, Od
             Ok(Event::Start(ref e)) if e.name() == QName(b"style:style") => {
                 style_name = e
                     .try_get_attribute(b"style:name")?
-                    .map(|a| a.decode_and_unescape_value(&reader))
+                    .map(|a| a.decode_and_unescape_value(reader.decoder()))
                     .transpose()
                     .map_err(OdsError::Xml)?
                     .map(|x| x.to_string())
@@ -317,7 +330,7 @@ fn parse_content<RS: Read + Seek>(mut zip: ZipArchive<RS>) -> Result<Content, Od
             {
                 let visible = match e.try_get_attribute(b"table:display")? {
                     Some(a) => match a
-                        .decode_and_unescape_value(&reader)
+                        .decode_and_unescape_value(reader.decoder())
                         .map_err(OdsError::Xml)?
                         .parse()
                         .map_err(OdsError::ParseBool)?
@@ -333,7 +346,7 @@ fn parse_content<RS: Read + Seek>(mut zip: ZipArchive<RS>) -> Result<Content, Od
                 let visible = styles
                     .get(
                         &e.try_get_attribute(b"table:style-name")?
-                            .map(|a| a.decode_and_unescape_value(&reader))
+                            .map(|a| a.decode_and_unescape_value(reader.decoder()))
                             .transpose()
                             .map_err(OdsError::Xml)?
                             .map(|x| x.to_string()),
@@ -346,7 +359,7 @@ fn parse_content<RS: Read + Seek>(mut zip: ZipArchive<RS>) -> Result<Content, Od
                     .find(|a| a.key == QName(b"table:name"))
                 {
                     let name = a
-                        .decode_and_unescape_value(&reader)
+                        .decode_and_unescape_value(reader.decoder())
                         .map_err(OdsError::Xml)?
                         .to_string();
                     let (range, formulas) = read_table(&mut reader)?;
@@ -388,7 +401,7 @@ fn read_table(reader: &mut OdsReader<'_>) -> Result<(Range<Data>, Range<String>)
             Ok(Event::Start(ref e)) if e.name() == QName(b"table:table-row") => {
                 let row_repeats = match e.try_get_attribute(b"table:number-rows-repeated")? {
                     Some(c) => c
-                        .decode_and_unescape_value(reader)
+                        .decode_and_unescape_value(reader.decoder())
                         .map_err(OdsError::Xml)?
                         .parse()
                         .map_err(OdsError::ParseInt)?,
@@ -603,7 +616,7 @@ fn get_datatype(
                 if !is_value_set =>
             {
                 let attr = a
-                    .decode_and_unescape_value(reader)
+                    .decode_and_unescape_value(reader.decoder())
                     .map_err(OdsError::Xml)?
                     .to_string();
                 val = match a.key {
@@ -621,7 +634,7 @@ fn get_datatype(
             QName(b"office:value-type") if !is_value_set => is_string = &*a.value == b"string",
             QName(b"table:formula") => {
                 formula = a
-                    .decode_and_unescape_value(reader)
+                    .decode_and_unescape_value(reader.decoder())
                     .map_err(OdsError::Xml)?
                     .to_string();
             }
@@ -664,7 +677,7 @@ fn get_datatype(
                 Ok(Event::Start(ref e)) if e.name() == QName(b"text:s") => {
                     let count = match e.try_get_attribute("text:c")? {
                         Some(c) => c
-                            .decode_and_unescape_value(reader)
+                            .decode_and_unescape_value(reader.decoder())
                             .map_err(OdsError::Xml)?
                             .parse()
                             .map_err(OdsError::ParseInt)?,
@@ -701,13 +714,13 @@ fn read_named_expressions(reader: &mut OdsReader<'_>) -> Result<Vec<(String, Str
                     match a.key {
                         QName(b"table:name") => {
                             name = a
-                                .decode_and_unescape_value(reader)
+                                .decode_and_unescape_value(reader.decoder())
                                 .map_err(OdsError::Xml)?
                                 .to_string();
                         }
                         QName(b"table:cell-range-address" | b"table:expression") => {
                             formula = a
-                                .decode_and_unescape_value(reader)
+                                .decode_and_unescape_value(reader.decoder())
                                 .map_err(OdsError::Xml)?
                                 .to_string();
                         }
