@@ -195,13 +195,8 @@ impl<'a> XlsxCellReader<'a> {
                                     // shared index
                                     let shared_index =
                                         match get_attribute(e.attributes(), QName(b"si"))? {
-                                            Some(res) => match std::str::from_utf8(res) {
-                                                Ok(res) => match res.parse::<usize>() {
-                                                    Ok(res) => res,
-                                                    Err(e) => {
-                                                        return Err(XlsxError::ParseInt(e));
-                                                    }
-                                                },
+                                            Some(res) => match atoi_simd::parse::<usize>(res) {
+                                                Ok(res) => res,
                                                 Err(_) => {
                                                     return Err(XlsxError::Unexpected(
                                                         "si attribute must be a number",
@@ -332,10 +327,7 @@ fn read_v<'s>(
 ) -> Result<DataRef<'s>, XlsxError> {
     let cell_format = match get_attribute(c_element.attributes(), QName(b"s")) {
         Ok(Some(style)) => {
-            let id: usize = std::str::from_utf8(style)
-                .unwrap_or("0")
-                .parse()
-                .unwrap_or(0);
+            let id = atoi_simd::parse::<usize>(style).unwrap_or(0);
             formats.get(id)
         }
         _ => Some(&CellFormat::Other),
@@ -343,7 +335,7 @@ fn read_v<'s>(
     match get_attribute(c_element.attributes(), QName(b"t"))? {
         Some(b"s") => {
             // shared string
-            let idx: usize = v.parse()?;
+            let idx = atoi_simd::parse::<usize>(v.as_bytes()).unwrap_or(0);
             Ok(DataRef::SharedString(&strings[idx]))
         }
         Some(b"b") => {
@@ -359,17 +351,8 @@ fn read_v<'s>(
             Ok(DataRef::DateTimeIso(v))
         }
         Some(b"str") => {
-            // see http://officeopenxml.com/SScontentOverview.php
-            // str - refers to formula cells
-            // * <c .. t='v' .. > indicates calculated value (this case)
-            // * <c .. t='f' .. > to the formula string (ignored case
-            // TODO: Fully support a Data::Formula representing both Formula string &
-            // last calculated value?
-            //
-            // NB: the result of a formula may not be a numeric value (=A3&" "&A4).
-            // We do try an initial parse as Float for utility, but fall back to a string
-            // representation if that fails
-            v.parse().map(DataRef::Float).or(Ok(DataRef::String(v)))
+            // string
+            Ok(DataRef::String(v))
         }
         Some(b"n") => {
             // n - number
